Module style

Module style 

Functions

load_css
load_user_css
Load and apply the user’s custom ~/.config/nmrs/style.css. If the file does not exist it is created with the bundled defaults. This must be called after any theme provider is registered so that same-priority (STYLE_PROVIDER_PRIORITY_USER) rules resolve in favour of the user’s stylesheet.